@@ -5,7 +5,7 @@ import json
 import logging
 import os
 import sys
-from typing import IO, Optional, List, Union
+from typing import IO, Optional, List, Union, Tuple
 
 from elasticsearch import helpers as es_helpers
 from elasticsearch import exceptions as esExceptions
@@ -213,7 +213,7 @@ def parse_upload(informat, lexname, lexOrder, data, index, typ, with_id=False):
 #     return to_keep
 
 
-def recover(alias, suffix, lexicon, create_new=True) -> bool:
+def recover(alias, suffix, lexicon, create_new=True) -> Tuple[bool, str]:
     """ Recovers the data to ES, uses SQL as the trusted base version.
         Find the last version of every SQL entry and send this to ES.
     """
@@ -240,7 +240,7 @@ def recover(alias, suffix, lexicon, create_new=True) -> bool:
                Message: %s.\n"
         raise Exception(msg % (ok, "\n".join(err)))
     print("recovery done")
-    return True
+    return True, index
 
 
 # def recover_add(index, suffix, lexicon):
@@ -296,12 +296,13 @@ def printlatestversion(lexicon: str, with_id: bool = False, fp: Optional[IO[str]
 
 def publish_mode(mode, suffix):
     index = make_indexname(mode, suffix)
+    _logger.info("Publishing mode '%s' to index '%s'", mode, index)
     add_actions = []
     rem_actions = []
     for alias in conf_mgr.get_modes_that_include_mode(mode):
         add_actions.append('{"add" : {"index": "%s", "alias": "%s"}}' % (index, alias))
         rem_actions.append('{"remove": {"index":"%s_*", "alias":"%s"}}' % (mode, alias))
-    print("remove {}".format(rem_actions))
+    _logger.debug("remove %s", rem_actions)
     print("add {}".format(add_actions))
 
     es = conf_mgr.elastic(mode)
@@ -312,7 +313,7 @@ def publish_mode(mode, suffix):
             '{"actions" : [%s]}' % ",".join(rem_actions), request_timeout=30
         )  # pylint: disable=unexpected-keyword-arg
     except esExceptions.ElasticsearchException:
-        print("No previous aliased indices, could not do remove any")
+        _logger.info("No previous aliased indices, could not do remove any")
         print(rem_actions)
 
     return es.indices.update_aliases(  # pylint: disable=unexpected-keyword-arg
